Lazy

Struct Lazy 

pub struct Lazy<T, TL: ThreadLocality = Shared, F = fn() -> T> { /* private fields */ }

Implementations

Source

impl<T, F: FnOnce() -> T> Lazy<T, Local, F>

pub unsafe fn reset(&mut self, new: F)

Safety

This can only be called by pthread destructors, to clear the thread-local storage.

Source

impl<T, TL: ThreadLocality, F: FnOnce() -> T> Lazy<T, TL, F>

pub const fn new(f: F) -> Self

pub fn force(lazy: &Self)

pub unsafe fn as_initialized(&self) -> &T

Load the value and assume it has been initialized

Safety

This function is unsafe because it does not check if the value has been initialized.